#ifdef GL_ES
precision mediump float;
#endif
varying vec4 v_color;
varying vec2 v_texCoords;
uniform sampler2D u_texture;
uniform float u_decayrate;
uniform float u_lightid;
uniform float u_size;
uniform float u_maxintensity;

const float PI = 3.14159265358979323;
const float inv2pi = 0.1591549430918953;
const float walldecay = 2.0;
const float samplecount = 1024.;
const float maxsize = 100.;
const float default_wall_pen = 0.03;

float sampleLight(float angle, float subangle) {
    vec4 raw = texture2D(u_texture, vec2(angle, u_lightid));
    return raw.r + raw.g/256.;
}

void main()
{
    // Calculations
    vec2 coords = v_texCoords - vec2(0.5);
    float norm_radius = length(coords) * 2.0;
    float norm_angle = atan(coords.y, coords.x) * inv2pi + 0.5;
    float angle_index = floor(norm_angle * samplecount + .5)/samplecount;
    float angle_fract = fract(norm_angle * samplecount + .5);
    float wall_radius0 = sampleLight(angle_index + 1./samplecount, angle_fract);
    float wall_radius1 = sampleLight(angle_index, angle_fract);
    float norm_wall_radius = mix(wall_radius1, wall_radius0, angle_fract) / 8.;
    float wall_pen = clamp(norm_radius*u_size - norm_wall_radius * maxsize - default_wall_pen, 0.0, 100.0);
    float intensity = smoothstep(0.0,1.0,u_decayrate/(norm_radius+walldecay*wall_pen) - u_decayrate);
    //intensity = clamp(0.0, 1.0, intensity);
    //intensity = smoothstep(0.0, 1.0, intensity);
    //intensity = smoothstep(0.0, 1.0, intensity);
    /*if(intensity < 0.9999) {
        intensity = 0.05;
    }
    if(angle_fract < 0.2) {
        intensity += 0.3;
        if (norm_radius*u_size > norm_wall_radius) intensity = 0.0;
        if(angle_fract < 0.2) {
            intensity += 0.0;
        }
    }
    if(angle_fract > 0.8 && wall_pen > 0.0001) {
        intensity = 1.0;
    }*/
    gl_FragColor.rgb = vec3(0.0);
    gl_FragColor.a = (1.0 + u_maxintensity * intensity)*0.5;
}
